@@ -210,7 +210,7 @@ class Bridge:
     DEFAULT_TIMEOUT = 500
     _EXPECTED_ZMQ_SERVER_VERSION = "4.2.0"
 
-    def __new__(cls, *args, **kwargs):
+    def __new__(cls, timeout: int=DEFAULT_TIMEOUT, convert_camel_case: bool=True,  *args, **kwargs):
         """
         Only one instance of Bridge per a thread/port combo
         """
@@ -222,6 +222,7 @@ class Bridge:
         if port not in Bridge.local.bridges.keys():
             Bridge.local.bridges[port] = []
             return super(Bridge, cls).__new__(cls)
+
         # clear old old refs that have been GCed
         remaining = []
         for i in range(len(Bridge.local.bridges[port])):
@@ -229,8 +230,8 @@ class Bridge:
                 remaining.append(Bridge.local.bridges[port][i])
         Bridge.local.bridges[port] = remaining
         if len(Bridge.local.bridges[port]) == 0:
-            return super(Bridge, cls).__new__(cls, timeout=timeout, convert_camel_case=convert_camel_case,
-                                              *args, **kwargs)
+            return super(Bridge, cls).__new__(cls)
+            
         return Bridge.local.bridges[port][0]()
 
 
